Scope Rest API — Rucio 1.2 documentation

# Scope Rest API

Overview

Resource | Operation | Description
--- | --- | ---
Scopes | POST /scopes/(account)/(scope) | Add a new scope.
| GET /scopes/ | Get all scopes.

Details

`POST` `/scopes/`(account)`/`(scope)

  Add a new scope.

  Response Headers:
  | Location – post url
  Status Codes: | 201 Created – scope created 404 Not Found – account does not exist 401 Unauthorized – unauthorized 409 Conflict – scope already exists 500 Internal Server Error – internal server error

`GET` `/scopes/`

  List all scopes.

  Example request:

      GET /posts/ HTTP/1.1
      Host: rucio.com

  Example response:

      HTTP/1.1 200 OK
      Vary: Accept
      Content-Type: application/json

      ["RSE1", "RSE2", "RSE3", "RSE4", "RSE5"]

  Response Headers:
  | Content-Type – application/json
  Status Codes: | 200 OK – scopes found
  Returns: | `String`